aboutsummaryrefslogtreecommitdiffhomepage
path: root/src/main/java/com/google/devtools/build/lib/actions
diff options
context:
space:
mode:
authorGravatar nharmata <nharmata@google.com>2018-08-06 08:44:47 -0700
committerGravatar Copybara-Service <copybara-piper@google.com>2018-08-06 08:46:06 -0700
commite74c1e91e68ce7c8eca6ab62100647d4b49f4597 (patch)
treeb4350bfac5317434c5688bc6b407446f1c2d7667 /src/main/java/com/google/devtools/build/lib/actions
parentdf0393cd2a78c357af339002b7c5fc135778cffe (diff)
Rename a param to better reflect its intent.
RELNOTES: None PiperOrigin-RevId: 207550943
Diffstat (limited to 'src/main/java/com/google/devtools/build/lib/actions')
-rw-r--r--src/main/java/com/google/devtools/build/lib/actions/FilesetTraversalParamsFactory.java12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/main/java/com/google/devtools/build/lib/actions/FilesetTraversalParamsFactory.java b/src/main/java/com/google/devtools/build/lib/actions/FilesetTraversalParamsFactory.java
index d1f94f072a..f9585f34df 100644
--- a/src/main/java/com/google/devtools/build/lib/actions/FilesetTraversalParamsFactory.java
+++ b/src/main/java/com/google/devtools/build/lib/actions/FilesetTraversalParamsFactory.java
@@ -117,7 +117,7 @@ public final class FilesetTraversalParamsFactory {
*
* @param ownerLabel the rule that created this object
* @param nested the list of traversal params that were used for the nested (inner) Fileset
* @param destDir path in the Fileset's output directory that will be the root of files coming
* from the nested Fileset
* @param excludes optional; set of files directly below (not in a subdirectory of) the nested
* Fileset that should be excluded from the outer Fileset
@@ -125,15 +125,15 @@ public final class FilesetTraversalParamsFactory {
public static FilesetTraversalParams nestedTraversal(
Label ownerLabel,
ImmutableList<FilesetTraversalParams> nested,
- PathFragment destDir,
+ PathFragment destPath,
@Nullable Set<String> excludes) {
- if (nested.size() == 1 && destDir.isEmpty() && (excludes == null || excludes.isEmpty())) {
+ if (nested.size() == 1 && destPath.isEmpty() && (excludes == null || excludes.isEmpty())) {
// Wrapping the traversal here would not lead to a different result: the output location is
// the same and there are no additional excludes.
return Iterables.getOnlyElement(nested);
}
// When srcdir is another Fileset, then files must be null so strip_prefix must also be null.
- return NestedTraversalParams.getNestedTraversal(ownerLabel, nested, destDir, excludes);
+ return NestedTraversalParams.getNestedTraversal(ownerLabel, nested, destPath, excludes);
}
private static ImmutableSortedSet<String> getOrderedExcludes(@Nullable Set<String> excludes) {
@@ -230,9 +230,9 @@ public final class FilesetTraversalParamsFactory {
static NestedTraversalParams getNestedTraversal(
Label ownerLabel,
ImmutableList<FilesetTraversalParams> nested,
- PathFragment destDir,
+ PathFragment destPath,
@Nullable Set<String> excludes) {
- return create(ownerLabel, destDir, getOrderedExcludes(excludes), nested);
+ return create(ownerLabel, destPath, getOrderedExcludes(excludes), nested);
}
@AutoCodec.VisibleForSerialization
@@ -117,7 +117,7 @@ public final class FilesetTraversalParamsFactory {
* @param ownerLabel the rule that created this object
* @param nested the list of traversal params that were used for the nested (inner) Fileset
- * @param destDir path in the Fileset's output directory that will be the root of files coming
+ * @param destPath path in the Fileset's output directory that will be the root of files coming
* from the nested Fileset
* @param excludes optional; set of files directly below (not in a subdirectory of) the nested